import { z } from 'zod';
import { Datasource } from '../datasource';
import type { GetReleasesConfig, ReleaseResult } from '../types';
interface VersionsEndpointUnsupported {
    versionsEndpointSupported: false;
}
type PackageVersions = Map<string, string[]>;
interface VersionsEndpointData {
    versionsEndpointSupported: true;
    packageVersions: PackageVersions;
    syncedAt: Date;
    contentLength: number;
    /**
     * Last 33 characters of the response (32 hex digits + newline)
     */
    contentTail: string;
}
type VersionsEndpointCache = VersionsEndpointUnsupported | VersionsEndpointData;
export declare const memCache: Map<string, VersionsEndpointCache>;
declare const VersionLines: z.ZodPipeline<z.ZodEffects<z.ZodString, string[], string>, z.ZodEffects<z.ZodArray<z.ZodAny, "many">, {
    packageName: string;
    deletedVersions: Set<string>;
    addedVersions: string[];
}[], any[]>>;
type VersionLines = z.infer<typeof VersionLines>;
export declare class VersionsDatasource extends Datasource {
    readonly id: string;
    constructor(id: string);
    static isStale(regCache: VersionsEndpointData): boolean;
    static reconcilePackageVersions(packageVersions: PackageVersions, versionLines: VersionLines): PackageVersions;
    private cacheRequests;
    /**
     * At any given time, there should only be one request for a given registryUrl.
     */
    private getCache;
    getReleases({ registryUrl, packageName, }: GetReleasesConfig): Promise<ReleaseResult | null>;
    fullSync(registryUrl: string): Promise<VersionsEndpointCache>;
    deltaSync(oldCache: VersionsEndpointData, registryUrl: string): Promise<VersionsEndpointCache>;
}
export {};
